@@ -8,11 +8,12 @@ import requests
 from lxml import html
 
 
-__version__ = '1.3'
+__version__ = '1.4'
 
 
 session = requests.Session()
-session.headers.update({"User-Agent": "Mozilla/5.0 (Windows NT 10.0; rv:91.0) Gecko/20100101 Firefox/91.0"})
+headers = {"User-Agent": "Mozilla/5.0 (Windows NT 10.0; rv:91.0) Gecko/20100101 Firefox/91.0"}
+session.headers.update(headers)
 
 
 
@@ -21,6 +22,7 @@ class MapsResult:
     ''' Dataclass for ddg_maps search results '''
     title: str = None
     address: str = None
+    country_code: str = None
     latitude: str = None
     longitude: str = None
     url: str = None
@@ -34,6 +36,8 @@ class MapsResult:
         
         
 def _normalize(text):
+    if not text:
+        return text
     body = html.fromstring(text)
     return html.tostring(body, method='text', encoding='unicode')
 
@@ -300,7 +304,7 @@ def ddg_maps(keywords, place=None, street=None, city=None, county=None, state=No
                 'polygon_geojson': '0',
                 'format': 'jsonv2',
                 }           
-        resp = requests.get('https://nominatim.openstreetmap.org/search.php', params=params)
+        resp = requests.get('https://nominatim.openstreetmap.org/search.php', params=params, headers=headers)
         coordinates = resp.json()[0]["boundingbox"]
         lat_t, lon_l = Decimal(coordinates[1]), Decimal(coordinates[2])
         lat_b, lon_r = Decimal(coordinates[0]), Decimal(coordinates[3])
@@ -343,6 +347,7 @@ def ddg_maps(keywords, place=None, street=None, city=None, county=None, state=No
                 continue
             else:
                 cache.add(r.title + r.address)
+                r.country_code = res["country_code"]
                 r.url = res["website"]
                 r.phone = res["phone"]
                 r.latitude = res["coordinates"]["latitude"]
@@ -356,7 +361,7 @@ def ddg_maps(keywords, place=None, street=None, city=None, county=None, state=No
                 results.append(r.__dict__)
 
         # divide the square into 4 parts and add to the queue
-        if len(data) == 20:
+        if len(data) >= 15:
             lat_middle = (lat_t + lat_b) / 2
             lon_middle = (lon_l + lon_r) / 2            
             bbox1 = (lat_t, lon_l, lat_middle, lon_middle)
